@@ -8,6 +8,9 @@
 #' @name RawDataGetters
 NULL
 
+
+## -------- getRawData --------
+
 #' @aliases getRawData
 #'
 #' @details `getRawData()` extracts the raw count table.
@@ -35,6 +38,8 @@ setMethod(
 )
 
 
+## -------- getNumCells --------
+
 #' @aliases getNumCells
 #'
 #' @details `getNumCells()` extracts the number of cells in the sample (\eqn{m})
@@ -59,6 +64,8 @@ setMethod(
 )
 
 
+## -------- getNumGenes --------
+
 #' @aliases getNumGenes
 #'
 #' @details `getNumGenes()` extracts the number of genes in the sample (\eqn{n})
@@ -83,6 +90,8 @@ setMethod(
 )
 
 
+## -------- getCells --------
+
 #' @aliases getCells
 #'
 #' @details `getCells()` extract all cells in the dataset.
@@ -107,6 +116,8 @@ setMethod(
 )
 
 
+## -------- getGenes --------
+
 #' @aliases getGenes
 #'
 #' @details `getGenes()` extract all genes in the dataset.
@@ -131,6 +142,8 @@ setMethod(
 )
 
 
+## -------- getZeroOneProj --------
+
 #' @aliases getZeroOneProj
 #'
 #' @details `getZeroOneProj()` extracts the raw count table where any
@@ -157,6 +170,8 @@ setMethod(
 )
 
 
+## -------- getCellsSize --------
+
 #' @aliases getCellsSize
 #'
 #' @details `getCellsSize()` extracts the cell raw library size.
@@ -183,6 +198,8 @@ setMethod(
 )
 
 
+## -------- getNumExpressedGenes --------
+
 #' @aliases getNumExpressedGenes
 #'
 #' @details `getNumExpressedGenes()` extracts the number of genes expressed for
@@ -211,6 +228,8 @@ setMethod(
 )
 
 
+## -------- getGenesSize --------
+
 #' @aliases getGenesSize
 #'
 #' @details `getGenesSize()` extracts the genes raw library size.
@@ -237,6 +256,8 @@ setMethod(
 )
 
 
+## -------- getNumOfExpressingCells --------
+
 #' @aliases getNumOfExpressingCells
 #'
 #' @details `getNumOfExpressingCells()` extracts, for each gene, the number of
@@ -282,6 +303,8 @@ setMethod(
 #' @name HandleMetaData
 NULL
 
+## -------- getMetadataDataset --------
+
 #' @aliases getMetadataDataset
 #'
 #' @details `getMetadataDataset()` extracts the meta-data stored for the
@@ -294,6 +317,8 @@ NULL
 #' @export
 #'
 #' @examples
+#' options(parallelly.fork.enable = TRUE)
+#'
 #' data("test.dataset")
 #' objCOTAN <- COTAN(raw = test.dataset)
 #'
@@ -316,6 +341,7 @@ setMethod(
   }
 )
 
+## -------- getMetadataElement --------
 
 #' @aliases getMetadataElement
 #'
@@ -327,12 +353,10 @@ setMethod(
 #'
 #' @returns `getMetadataElement()` returns a string with the relevant value
 #'
-#' @importFrom rlang is_empty
-#'
 #' @export
 #'
 #' @examples
-#' numInitialCells <- getMetadataElement(objCOTAN, "cells")
+#' numInitialCells <- getMetadataElement(objCOTAN, datasetTags()[["cells"]])
 #'
 #' @rdname HandleMetaData
 #'
@@ -341,18 +365,16 @@ setMethod(
   "COTAN",
   function(objCOTAN, tag) {
     meta <- getMetadataDataset(objCOTAN)
-
-    if (is_empty(meta) || !(tag %in% meta[[1L]])) {
-      out <- ""
+    rowPos <- getMetaInfoRow(meta, tag)
+    if (rowPos == 0L) {
+      return("")
     } else {
-      rowPos <- which(meta[[1L]] %in% tag)
-      out <- meta[, -1L, drop = FALSE][rowPos, ]
+      return(meta[, -1L, drop = FALSE][rowPos, ])
     }
-
-    return(out)
   }
 )
 
+## -------- getMetadataGenes --------
 
 #' @aliases getMetadataGenes
 #'
@@ -378,6 +400,8 @@ setMethod(
 )
 
 
+## -------- getMetadataCells --------
+
 #' @aliases getMetadataCells
 #'
 #' @details `getMetadataCells()` extracts the meta-data stored for the cells
@@ -402,6 +426,8 @@ setMethod(
 )
 
 
+## -------- getDims --------
+
 #' @aliases getDims
 #'
 #' @details `getDims()` extracts the sizes of all slots of the `COTAN` object
@@ -434,13 +460,16 @@ setMethod(
 
 # ------- `COTAN` estimated data accessors ------
 
+## -------- getNu --------
+
 #' @aliases getNu
 #'
-#' @details `getNu()` extracts the nu array (normalized cells' counts averages)
+#' @details `getNu()` extracts the `nu` array (normalized cells' counts
+#'   averages)
 #'
 #' @param objCOTAN a `COTAN` object
 #'
-#' @returns `getNu()` returns the nu array
+#' @returns `getNu()` returns the `nu` array
 #'
 #' @importFrom rlang is_empty
 #'
@@ -455,7 +484,7 @@ setMethod(
     nu <- getMetadataCells(objCOTAN)[["nu"]]
 
     if (is_empty(nu)) {
-      warning("nu is empty")
+      warning("`nu` is empty")
     } else {
       names(nu) <- getCells(objCOTAN)
     }
@@ -465,14 +494,16 @@ setMethod(
 )
 
 
+## -------- getLambda --------
+
 #' @aliases getLambda
 #'
-#' @details `getLambda()` extracts the lambda array (mean expression for each
+#' @details `getLambda()` extracts the `lambda` array (mean expression for each
 #'   gene)
 #'
 #' @param objCOTAN a `COTAN` object
 #'
-#' @returns `getLambda()` returns the lambda array
+#' @returns `getLambda()` returns the `lambda` array
 #'
 #' @importFrom rlang is_empty
 #'
@@ -487,7 +518,7 @@ setMethod(
     lambda <- getMetadataGenes(objCOTAN)[["lambda"]]
 
     if (is_empty(lambda)) {
-      warning("lambda is empty")
+      warning("`lambda` is empty")
     } else {
       names(lambda) <- getGenes(objCOTAN)
     }
@@ -497,13 +528,16 @@ setMethod(
 )
 
 
+## -------- getDispersion --------
+
 #' @aliases getDispersion
 #'
-#' @details `getDispersion()` extracts the dispersion array
+#' @details `getDispersion()` extracts the `dispersion` array (one value for
+#'   each gene)
 #'
 #' @param objCOTAN a `COTAN` object
 #'
-#' @returns `getDispersion()` returns the dispersion array
+#' @returns `getDispersion()` returns the `dispersion` array
 #'
 #' @importFrom rlang is_empty
 #'
@@ -518,7 +552,7 @@ setMethod(
     dispersion <- getMetadataGenes(objCOTAN)[["dispersion"]]
 
     if (is_empty(dispersion)) {
-      warning("dispersion is empty")
+      warning("`dispersion` is empty")
     } else {
       names(dispersion) <- getGenes(objCOTAN)
     }
@@ -528,8 +562,10 @@ setMethod(
 )
 
 
-#' @details `estimatorsAreReady()` checks whether the estimators arrays lambda,
-#'   nu, dispersion are available
+## -------- estimatorsAreReady --------
+
+#' @details `estimatorsAreReady()` checks whether the estimators arrays
+#'   `lambda`, `nu`, `dispersion` are available
 #'
 #' @param objCOTAN a `COTAN` object
 #'
@@ -547,15 +583,17 @@ estimatorsAreReady <- function(objCOTAN) {
                     is_empty(getNu(objCOTAN)) ||
                     is_empty(getDispersion(objCOTAN))
   if (anyEmptyArrays) {
-    logThis(paste0("Estimators are not ready - array sizes: lambda ",
-                   length(getLambda(objCOTAN)), ", nu ",
-                   length(getNu(objCOTAN)), ", dispersion ",
+    logThis(paste0("Estimators are not ready - array sizes: `lambda` ",
+                   length(getLambda(objCOTAN)), ", `nu` ",
+                   length(getNu(objCOTAN)), ", `dispersion` ",
                    length(getDispersion(objCOTAN))), logLevel = 2L)
   }
   return(!anyEmptyArrays)
 }
 
 
+## -------- getMu --------
+
 #' @aliases getMu
 #' @aliases calculateMu
 #'
@@ -573,18 +611,20 @@ estimatorsAreReady <- function(objCOTAN) {
 #' @rdname CalculatingCOEX
 #'
 getMu <- function(objCOTAN) {
-  if (is_empty(getLambda(objCOTAN))) {
-    stop("lambda must not be empty, estimate it")
-  }
+  lambda <- suppressWarnings(getLambda(objCOTAN))
+  assert_that(!is_empty(lambda),
+              msg = "`lambda` must not be empty, estimate it")
 
-  if (is_empty(getNu(objCOTAN))) {
-    stop("nu must not be empty, estimate it")
-  }
+  nu <- suppressWarnings(getNu(objCOTAN))
+  assert_that(!is_empty(nu),
+              msg = "`nu` must not be empty, estimate it")
 
-  return(getLambda(objCOTAN) %o% getNu(objCOTAN))
+  return(lambda %o% nu)
 }
 
 
+## -------- getNuNormData --------
+
 #' @details `getNuNormData()` extracts the \eqn{\nu}*-normalized* count table
 #'   (i.e. where each column is divided by `nu`) and returns it
 #'
@@ -603,13 +643,16 @@ getMu <- function(objCOTAN) {
 #' @rdname ParametersEstimations
 #'
 getNuNormData <- function(objCOTAN) {
-  if (is_empty(getNu(objCOTAN))) {
-    stop("nu must not be empty, estimate it")
-  }
+  nu <- suppressWarnings(getNu(objCOTAN))
+  assert_that(!is_empty(nu),
+              msg = "`nu` must not be empty, estimate it")
 
-  return(t(t(getRawData(objCOTAN)) * (1.0 / getNu(objCOTAN))))
+  return(t(t(getRawData(objCOTAN)) * (1.0 / nu)))
 }
 
+
+## -------- getLogNormData --------
+
 #' @details `getLogNormData()` extracts the *log-normalized* count table (i.e.
 #'   where each column is divided by the [getCellsSize()]), takes its `log10`
 #'   and returns it.
@@ -634,6 +677,9 @@ getLogNormData <- function(objCOTAN) {
   return(log1p(normData) / log(10.0))
 }
 
+
+## -------- getNormalizedData --------
+
 #' @details `getNormalizedData()` is deprecated: please use [getNuNormData()] or
 #'   [getLogNormData()] directly as appropriate
 #'
@@ -658,6 +704,8 @@ getNormalizedData <- function(objCOTAN, retLog = FALSE) {
 }
 
 
+## -------- getProbabilityOfZero --------
+
 #' @details `getProbabilityOfZero()` gives for each cell and each gene the
 #'   probability of observing zero reads
 #'
@@ -676,12 +724,12 @@ getNormalizedData <- function(objCOTAN, retLog = FALSE) {
 #' @rdname ParametersEstimations
 #'
 getProbabilityOfZero <- function(objCOTAN) {
-  if (is_empty(getDispersion(objCOTAN))) {
-    stop("dispersion must not be empty, estimate it")
-  }
+  dispersion <- suppressWarnings(getDispersion(objCOTAN))
+  assert_that(!is_empty(dispersion),
+              msg = "`dispersion` must not be empty, estimate it")
 
   # estimate Probabilities of 0 with internal function funProbZero
-  return(funProbZero(getDispersion(objCOTAN), getMu(objCOTAN)))
+  return(funProbZero(dispersion, getMu(objCOTAN)))
 }
 
 
@@ -838,6 +886,8 @@ setMethod(
 #' @name CalculatingCOEX
 NULL
 
+## -------- getGenesCoex --------
+
 #' @aliases getGenesCoex
 #'
 #' @details `getGenesCoex()` extracts a complete (or a partial after genes
@@ -861,6 +911,8 @@ NULL
 #' @export
 #'
 #' @examples
+#' options(parallelly.fork.enable = TRUE)
+#'
 #' data("test.dataset")
 #' objCOTAN <- COTAN(raw = test.dataset)
 #' objCOTAN <- initializeMetaDataset(objCOTAN, GEO = "test_GEO",
@@ -868,7 +920,8 @@ NULL
 #'                                   sampleCondition = "reconstructed_dataset")
 #' objCOTAN <- clean(objCOTAN)
 #'
-#' objCOTAN <- estimateDispersionBisection(objCOTAN, cores = 6L)
+#' objCOTAN <- estimateLambdaLinear(objCOTAN)
+#' objCOTAN <- estimateDispersionViaSolver(objCOTAN, cores = 6L)
 #'
 #' ## Now the `COTAN` object is ready to calculate the genes' `COEX`
 #'
@@ -887,8 +940,11 @@ NULL
 #' partialGenesCoex <- calculatePartialCoex(objCOTAN, genesSample,
 #'                                          actOnCells = FALSE)
 #'
-#' identical(partialGenesCoex,
-#'           getGenesCoex(objCOTAN, getGenes(objCOTAN)[sort(genesSample)]))
+#' stopifnot(all(5.0e-6 >
+#'                 abs(partialGenesCoex -
+#'                       getGenesCoex(objCOTAN,
+#'                                    getGenes(objCOTAN)[sort(genesSample)],
+#'                                    zeroDiagonal = FALSE))))
 #'
 #' ## S <- calculateS(objCOTAN)
 #' ## G <- calculateG(objCOTAN)
@@ -896,8 +952,9 @@ NULL
 #' gdiDF <- calculateGDI(objCOTAN)
 #' objCOTAN <- storeGDI(objCOTAN, genesGDI = gdiDF)
 #'
-#' ## Touching any of the lambda/nu/dispersino parameters invalidates the `COEX`
-#' ## matrix and derivatives, so it can be dropped it from the `COTAN` object
+#' ## Touching any of the `lambda`/`nu`/`dispersion` parameters invalidates the
+#' ## `COEX` matrix and derivatives, so it can be dropped it from the `COTAN`
+#' ## object
 #' objCOTAN <- dropGenesCoex(objCOTAN)
 #' stopifnot(!isCoexAvailable(objCOTAN))
 #'
@@ -905,23 +962,24 @@ NULL
 #' objCOTAN <- estimateDispersionNuBisection(objCOTAN, cores = 6L)
 #'
 #' ## Now the `COTAN` object is ready to calculate the cells' `COEX`
-#' ## In case one need to caclualte both it is more sensible to run the above
+#' ## In case one needs to calculate both, it is more sensible to run the above
 #' ## before any `COEX` evaluation
 #'
 #' g1 <- getGenes(objCOTAN)[sample(getNumGenes(objCOTAN), 1)]
-#' g2 <- getGenes(objCOTAN)[sample(getNumGenes(objCOTAN), 1)]
+#' g2 <- getGenes(objCOTAN)[138L]
 #' tables <- contingencyTables(objCOTAN, g1 = g1, g2 = g2)
 #' tables
 #'
 #' objCOTAN <- calculateCoex(objCOTAN, actOnCells = TRUE)
 #' stopifnot(isCoexAvailable(objCOTAN, actOnCells = TRUE, ignoreSync = TRUE))
-#' cellsCoex <- getCellsCoex(objCOTAN)
+#' cellsCoex <- getCellsCoex(objCOTAN, zeroDiagonal = FALSE)
 #'
 #' cellsSample <- sample(getNumCells(objCOTAN), 10)
 #' partialCellsCoex <- calculatePartialCoex(objCOTAN, cellsSample,
 #'                                          actOnCells = TRUE)
 #'
-#' identical(partialCellsCoex, cellsCoex[, sort(cellsSample)])
+#' stopifnot(all(1e-6 >
+#'                 abs(partialCellsCoex - cellsCoex[, sort(cellsSample)])))
 #'
 #' objCOTAN <- dropCellsCoex(objCOTAN)
 #' stopifnot(!isCoexAvailable(objCOTAN, actOnCells = TRUE))
@@ -937,7 +995,7 @@ setMethod(
 
     if (is_empty(genes)) {
       assert_that(coexIsReady,
-                  msg = paste0("Cannot return genes' coex as the matrix was ",
+                  msg = paste0("Cannot return genes' COEX as the matrix was ",
                                "never calculated or is out-of-sync with the ",
                                "estimators."))
 
@@ -953,7 +1011,7 @@ setMethod(
       ret <- objCOTAN@genesCoex
 
       if (!coexIsReady) {
-        warning("Missing or out-of-sync genes' coex:",
+        warning("Missing or out-of-sync genes' COEX:",
                 "calculating the required subset now!")
         ret <- calculatePartialCoex(objCOTAN, columnsSubset = genes,
                                     actOnCells = FALSE)
@@ -971,6 +1029,8 @@ setMethod(
 )
 
 
+## -------- getCellsCoex --------
+
 #' @aliases getCellsCoex
 #'
 #' @details `getCellsCoex()` extracts a complete (or a partial after cells
@@ -1002,7 +1062,7 @@ setMethod(
 
     if (is_empty(cells)) {
       assert_that(coexIsReady,
-                  msg = paste0("Cannot return cells' coex as the matrix was ",
+                  msg = paste0("Cannot return cells' COEX as the matrix was ",
                                "never calculated or is out-of-sync with the ",
                                "estimators."))
 
@@ -1018,7 +1078,7 @@ setMethod(
       ret <- objCOTAN@cellsCoex
 
       if (!coexIsReady) {
-        warning("Missing or out-of-sync cells' coex:",
+        warning("Missing or out-of-sync cells' COEX:",
                 "calculating the required subset now!")
         ret <- calculatePartialCoex(objCOTAN, columnsSubset = cells,
                                     actOnCells = TRUE)
@@ -1036,6 +1096,8 @@ setMethod(
 )
 
 
+## -------- isCoexAvailable --------
+
 #' @aliases isCoexAvailable
 #'
 #' @details `isCoexAvailable()` allows to query whether the relevant `COEX`
@@ -1061,28 +1123,32 @@ setMethod(
   "COTAN",
   function(objCOTAN, actOnCells = FALSE, ignoreSync = FALSE) {
     if (isTRUE(actOnCells)) {
-      isInSync <- as.logical(getMetadataElement(objCOTAN,
-                                                datasetTags()[["csync"]]))
+      isInSync <-
+        as.logical(getMetadataElement(objCOTAN, datasetTags()[["csync"]])[[1L]])
 
-      return(!is_empty(objCOTAN@cellsCoex) && (isTRUE(ignoreSync) || isInSync))
+      return(!is_empty(objCOTAN@cellsCoex) &&
+               (isTRUE(ignoreSync) || isTRUE(isInSync)))
     } else {
-      isInSync <- as.logical(getMetadataElement(objCOTAN,
-                                                datasetTags()[["gsync"]]))
+      isInSync <-
+        as.logical(getMetadataElement(objCOTAN, datasetTags()[["gsync"]])[[1L]])
 
-      return(!is_empty(objCOTAN@genesCoex) && (isTRUE(ignoreSync) || isInSync))
+      return(!is_empty(objCOTAN@genesCoex) &&
+               (isTRUE(ignoreSync) || isTRUE(isInSync)))
     }
   }
 )
 
 
+## -------- getGDI --------
+
 #' @aliases getGDI
 #'
-#' @details `getGDI()` extracts the genes' **GDI** array as it was stored by the
+#' @details `getGDI()` extracts the genes' `GDI` array as it was stored by the
 #'   method [storeGDI()]
 #'
 #' @param objCOTAN a `COTAN` object
 #'
-#' @returns `getGDI()` returns the genes' **GDI** array if available or `NULL`
+#' @returns `getGDI()` returns the genes' `GDI`` array if available or `NULL`
 #'   otherwise
 #'
 #' @importFrom rlang is_empty
@@ -1108,6 +1174,8 @@ setMethod(
 )
 
 
+## -------- getClusterizations --------
+
 #' @aliases getClusterizations
 #'
 #' @details `getClusterizations()` extracts the list of the *clusterizations*
@@ -1115,7 +1183,7 @@ setMethod(
 #'
 #' @param objCOTAN a `COTAN` object
 #' @param dropNoCoex When `TRUE` drops the names from the *clusterizations* with
-#'   empty associated coex `data.frame`
+#'   empty associated `COEX` `data.frame`
 #' @param keepPrefix When `TRUE` returns the internal name of the
 #'   *clusterization*: the one with the `CL_` prefix.
 #'
@@ -1131,7 +1199,7 @@ setMethod(
 #' @examples
 #' data("test.dataset")
 #' objCOTAN <- COTAN(raw = test.dataset)
-#' objCOTAN <- proceedToCoex(objCOTAN, cores = 6L, calcCoex = FALSE,
+#' objCOTAN <- proceedToCoex(objCOTAN, cores = 6L, calcCoex = TRUE,
 #'                           optimizeForSpeed = TRUE, saveObj = FALSE)
 #'
 #' data("test.dataset.clusters1")
@@ -1139,7 +1207,7 @@ setMethod(
 #'
 #' coexDF <- DEAOnClusters(objCOTAN, clusters = clusters)
 #'
-#' groupMarkers <- list(G1 = c("g-000010", "g-000020", "g-000030",
+#' groupMarkers <- list(G1 = c("g-000010", "g-000020", "g-000138",
 #'                             "g-000150", "g-000160", "g-000170"),
 #'                      G2 = c("g-000300", "g-000330", "g-000450",
 #'                             "g-000460", "g-000470"),
@@ -1159,7 +1227,9 @@ setMethod(
 #' umapPlot2 <- UMAPPlot(lfcDF, clusters = geneClusters)
 #' plot(umapPlot2)
 #'
-#' objCOTAN <- estimateNuLinearByCluster(objCOTAN, clusters = clusters)
+#' if (FALSE) {
+#'   objCOTAN <- estimateNuLinearByCluster(objCOTAN, clusters = clusters)
+#' }
 #'
 #' clSummaryPlotAndData <-
 #'   clustersSummaryPlot(objCOTAN, clName = "first_clusterization",
@@ -1173,24 +1243,28 @@ setMethod(
 #' clusterizations <- getClusterizations(objCOTAN, dropNoCoex = TRUE)
 #' stopifnot(length(clusterizations) == 1)
 #'
-#' cellsUmapPlotAndDF <- cellsUMAPPlot(objCOTAN, dataMethod = "LogNormalized",
-#'                                     clName = "first_clusterization",
-#'                                     genesSel = "HVG_Seurat")
+#' cellsUmapPlotAndDF <- cellsUMAPPlot(objCOTAN, dataMethod = "LogLikelihood",
+#'                                     useCoexEigen = TRUE, numComp = 25L,
+#'                                     clName = "first_clusterization")
 #' plot(cellsUmapPlotAndDF[["plot"]])
 #'
 #' enrichment <- geneSetEnrichment(clustersCoex = coexDF,
 #'                                 groupMarkers = groupMarkers)
 #'
 #' clHeatmapPlotAndData <- clustersMarkersHeatmapPlot(objCOTAN, groupMarkers)
+#' clHeatmapPlotAndData[["heatmapPlot"]]
 #'
 #' conditions <- as.integer(substring(getCells(objCOTAN), 3L))
 #' conditions <- factor(ifelse(conditions <= 600, "L", "H"))
 #' names(conditions) <- getCells(objCOTAN)
 #'
+#' objCOTAN <- addCondition(objCOTAN, condName = "High/Low",
+#'                          conditions = conditions)
+#'
 #' clHeatmapPlotAndData2 <-
 #'   clustersMarkersHeatmapPlot(objCOTAN, groupMarkers, kCuts = 2,
-#'                              condNameList = list("High/Low"),
-#'                              conditionsList = list(conditions))
+#'                              condNameList = list("High/Low"))
+#' clHeatmapPlotAndData2[["heatmapPlot"]]
 #'
 #' @rdname HandlingClusterizations
 #'
@@ -1218,6 +1292,9 @@ setMethod(
   }
 )
 
+
+## -------- getClusterizationName --------
+
 #' @aliases getClusterizationName
 #'
 #' @details `getClusterizationName()` normalizes the given *clusterization* name
@@ -1270,6 +1347,9 @@ setMethod(
   }
 )
 
+
+## -------- getClusterizationData --------
+
 #' @aliases getClusterizationData
 #'
 #' @details `getClusterizationData()` extracts the asked *clusterization* and
@@ -1315,7 +1395,9 @@ setMethod(
   }
 )
 
-#'
+
+## -------- getClusters --------
+
 #' @details `getClusters()` extracts the asked *clusterization* from the `COTAN`
 #'   object
 #'
@@ -1337,6 +1419,9 @@ getClusters <- function(objCOTAN, clName = "") {
   return(getClusterizationData(objCOTAN, clName = clName)[["clusters"]])
 }
 
+
+## -------- getClustersCoex --------
+
 #' @aliases getClustersCoex
 #'
 #' @details `getClustersCoex()` extracts the full `clusterCoex` member `list`
@@ -1376,6 +1461,9 @@ setMethod(
 #' @name HandlingConditions
 NULL
 
+
+## -------- getAllConditions --------
+
 #' @aliases getAllConditions
 #'
 #' @details `getAllConditions()` extracts the list of the *conditions* defined
@@ -1402,7 +1490,9 @@ NULL
 #' names(cellLine) <- getCells(objCOTAN)
 #' objCOTAN <- addCondition(objCOTAN, condName = "Line", conditions = cellLine)
 #'
-#' ##objCOTAN <- dropCondition(objCOTAN, "Genre")
+#' if (FALSE) {
+#'   objCOTAN <- dropCondition(objCOTAN, "Genre")
+#' }
 #'
 #' conditionsNames <- getAllConditions(objCOTAN)
 #'
@@ -1427,6 +1517,9 @@ setMethod(
   }
 )
 
+
+## -------- getConditionName --------
+
 #' @aliases getConditionName
 #'
 #' @details `getConditionName()` normalizes the given *condition* name or, if
@@ -1477,6 +1570,9 @@ setMethod(
   }
 )
 
+
+## -------- getCondition --------
+
 #' @aliases getCondition
 #'
 #' @details `getCondition()` extracts the asked *condition* from the `COTAN`
@@ -1518,6 +1614,8 @@ setMethod(
 )
 
 
+## -------- normalizeNameAndLabels --------
+
 #' @details `normalizeNameAndLabels()` takes a pair of name/labels and
 #'   normalize them based on the available information in the `COTAN` object
 #'
